Learn R Programming

grattan (version 1.5.2.5)

differentially_uprate_wage: Differential uprating

Description

Apply differential uprating to projections of the Sw_amt variable.

Usage

differentially_uprate_wage(wage = 1, from_fy, to_fy, ...)

Arguments

wage

A numeric vector to be uprated.

from_fy

The financial year contemporaneous to wage, which must be a financial year of an available sample file -- in particular, not after 2013-14.

to_fy

The target of the uprating. Passed to wage_inflator.

...

Other arguments passed wage_inflator.

Value

The vector wage differentially uprated to to_fy.

Details

See vignette("differential-uprating").

Examples

Run this code
# NOT RUN {
ws <- c(20e3, 50e3, 100e3)
from <- "2013-14"
to <- "2016-17"
differentially_uprate_wage(ws, from, to)
differentially_uprate_wage(ws, from, to) / wage_inflator(ws, from, to)
# }

Run the code above in your browser using DataLab