A function for simple projections of sample files
project_to(sample_file, to_fy, fy.year.of.sample.file = "2013-14", ...)A sample file, most likely the 2012-13 sample file. It is intended that to be the most recent.
A string like "1066-67" representing the financial year for which forecasts of the sample file are desired.
The financial year of sample_file.
Other arguments passed to project.
A sample file of the same number of rows as sample_file with inflated values (including WEIGHT).